import express from 'express';
import cors from 'cors';
import path from 'path';
import { PrismaClient } from '@prisma/client';
import YearEndService from './services/YearEndService';

// Импорт маршрутов
import authRoutes from './routes/auth.routes';
import adminRoutes from './routes/admin.routes';
import inventoryRoutes from './routes/inventory.routes';
import reportRoutes from './routes/report.routes';
import yearEndRoutes from './routes/yearEnd.routes';

const app = express();
const prisma = new PrismaClient();
const port = process.env.PORT || 4000;

// Middleware
app.use(cors({
  origin: 'https://todou.net',  // Разрешаем запросы с фронта
  credentials: true, // Разрешаем куки и авторизацию
  methods: 'GET,POST,PUT,DELETE,OPTIONS', // Разрешенные методы
  allowedHeaders: 'Content-Type,Authorization' // Разрешенные заголовки
}));
app.options('*', (req, res) => {
  res.header('Access-Control-Allow-Origin', 'https://todou.net');
  res.header('Access-Control-Allow-Methods', 'GET, POST, PUT, DELETE, OPTIONS');
  res.header('Access-Control-Allow-Headers', 'Content-Type, Authorization');
  res.header('Access-Control-Allow-Credentials', 'true');
  res.sendStatus(200);
});

app.use(express.json());

// API маршруты
app.use('/auth', authRoutes);
app.use('/admin', adminRoutes);
app.use('/inventory', inventoryRoutes);
app.use('/reports', reportRoutes);
app.use('/year-end', yearEndRoutes);

// Раздача статических файлов в production
if (process.env.NODE_ENV === 'production') {
  app.use(express.static(path.join(__dirname, '../../frontend/dist')));
  
  app.get('*', (req, res) => {
    res.sendFile(path.join(__dirname, '../../frontend/dist/index.html'));
  });
}

// Инициализация планировщика переноса остатков
YearEndService.initScheduler();

// Обработка ошибок
app.use((err: any, req: express.Request, res: express.Response, next: express.NextFunction) => {
  console.error(err.stack);
  res.status(500).json({ message: 'Что-то пошло не так!' });
});

// Запуск сервера
app.listen(port, () => {
  console.log(`Server is running on port ${port}`);
});

// Graceful shutdown
process.on('SIGTERM', async () => {
  console.log('SIGTERM received. Closing HTTP server and database connections...');
  await prisma.$disconnect();
  process.exit(0);
}); 